
:orphan:

.. _sphx_glr_auto_examples_sg_execution_times:

Computation times
=================
**00:00.808** total execution time for **auto_examples** files:

- **00:00.437**: :ref:`sphx_glr_auto_examples_plot_vfi_classifier_dicision_boundaries.py` (``plot_vfi_classifier_dicision_boundaries.py``)
- **00:00.371**: :ref:`sphx_glr_auto_examples_plot_sensitivity_analysis.py` (``plot_sensitivity_analysis.py``)
